# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/services/campaign_group_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v0.proto.resources import campaign_group_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__group__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/services/campaign_group_service.proto',
  package='google.ads.googleads.v0.services',
  syntax='proto3',
  serialized_pb=_b('\nCgoogle/ads/googleads_v0/proto/services/campaign_group_service.proto\x12 google.ads.googleads.v0.services\x1a<google/ads/googleads_v0/proto/resources/campaign_group.proto\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\"0\n\x17GetCampaignGroupRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"\x80\x01\n\x1bMutateCampaignGroupsRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12L\n\noperations\x18\x02 \x03(\x0b\x32\x38.google.ads.googleads.v0.services.CampaignGroupOperation\"\xf0\x01\n\x16\x43\x61mpaignGroupOperation\x12/\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x42\n\x06\x63reate\x18\x01 \x01(\x0b\x32\x30.google.ads.googleads.v0.resources.CampaignGroupH\x00\x12\x42\n\x06update\x18\x02 \x01(\x0b\x32\x30.google.ads.googleads.v0.resources.CampaignGroupH\x00\x12\x10\n\x06remove\x18\x03 \x01(\tH\x00\x42\x0b\n\toperation\"l\n\x1cMutateCampaignGroupsResponse\x12L\n\x07results\x18\x02 \x03(\x0b\x32;.google.ads.googleads.v0.services.MutateCampaignGroupResult\"2\n\x19MutateCampaignGroupResult\x12\x15\n\rresource_name\x18\x01 \x01(\t2\xaa\x03\n\x14\x43\x61mpaignGroupService\x12\xb9\x01\n\x10GetCampaignGroup\x12\x39.google.ads.googleads.v0.services.GetCampaignGroupRequest\x1a\x30.google.ads.googleads.v0.resources.CampaignGroup\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/v0/{resource_name=customers/*/campaignGroups/*}\x12\xd5\x01\n\x14MutateCampaignGroups\x12=.google.ads.googleads.v0.services.MutateCampaignGroupsRequest\x1a>.google.ads.googleads.v0.services.MutateCampaignGroupsResponse\">\x82\xd3\xe4\x93\x02\x38\"3/v0/customers/{customer_id=*}/campaignGroups:mutate:\x01*B\xd9\x01\n$com.google.ads.googleads.v0.servicesB\x19\x43\x61mpaignGroupServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V0.Services\xca\x02 Google\\Ads\\GoogleAds\\V0\\Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__group__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,])




_GETCAMPAIGNGROUPREQUEST = _descriptor.Descriptor(
  name='GetCampaignGroupRequest',
  full_name='google.ads.googleads.v0.services.GetCampaignGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.GetCampaignGroupRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=231,
  serialized_end=279,
)


_MUTATECAMPAIGNGROUPSREQUEST = _descriptor.Descriptor(
  name='MutateCampaignGroupsRequest',
  full_name='google.ads.googleads.v0.services.MutateCampaignGroupsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v0.services.MutateCampaignGroupsRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operations', full_name='google.ads.googleads.v0.services.MutateCampaignGroupsRequest.operations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=282,
  serialized_end=410,
)


_CAMPAIGNGROUPOPERATION = _descriptor.Descriptor(
  name='CampaignGroupOperation',
  full_name='google.ads.googleads.v0.services.CampaignGroupOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='google.ads.googleads.v0.services.CampaignGroupOperation.update_mask', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create', full_name='google.ads.googleads.v0.services.CampaignGroupOperation.create', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update', full_name='google.ads.googleads.v0.services.CampaignGroupOperation.update', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='google.ads.googleads.v0.services.CampaignGroupOperation.remove', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='operation', full_name='google.ads.googleads.v0.services.CampaignGroupOperation.operation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=413,
  serialized_end=653,
)


_MUTATECAMPAIGNGROUPSRESPONSE = _descriptor.Descriptor(
  name='MutateCampaignGroupsResponse',
  full_name='google.ads.googleads.v0.services.MutateCampaignGroupsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v0.services.MutateCampaignGroupsResponse.results', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=655,
  serialized_end=763,
)


_MUTATECAMPAIGNGROUPRESULT = _descriptor.Descriptor(
  name='MutateCampaignGroupResult',
  full_name='google.ads.googleads.v0.services.MutateCampaignGroupResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.MutateCampaignGroupResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=765,
  serialized_end=815,
)

_MUTATECAMPAIGNGROUPSREQUEST.fields_by_name['operations'].message_type = _CAMPAIGNGROUPOPERATION
_CAMPAIGNGROUPOPERATION.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_CAMPAIGNGROUPOPERATION.fields_by_name['create'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__group__pb2._CAMPAIGNGROUP
_CAMPAIGNGROUPOPERATION.fields_by_name['update'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__group__pb2._CAMPAIGNGROUP
_CAMPAIGNGROUPOPERATION.oneofs_by_name['operation'].fields.append(
  _CAMPAIGNGROUPOPERATION.fields_by_name['create'])
_CAMPAIGNGROUPOPERATION.fields_by_name['create'].containing_oneof = _CAMPAIGNGROUPOPERATION.oneofs_by_name['operation']
_CAMPAIGNGROUPOPERATION.oneofs_by_name['operation'].fields.append(
  _CAMPAIGNGROUPOPERATION.fields_by_name['update'])
_CAMPAIGNGROUPOPERATION.fields_by_name['update'].containing_oneof = _CAMPAIGNGROUPOPERATION.oneofs_by_name['operation']
_CAMPAIGNGROUPOPERATION.oneofs_by_name['operation'].fields.append(
  _CAMPAIGNGROUPOPERATION.fields_by_name['remove'])
_CAMPAIGNGROUPOPERATION.fields_by_name['remove'].containing_oneof = _CAMPAIGNGROUPOPERATION.oneofs_by_name['operation']
_MUTATECAMPAIGNGROUPSRESPONSE.fields_by_name['results'].message_type = _MUTATECAMPAIGNGROUPRESULT
DESCRIPTOR.message_types_by_name['GetCampaignGroupRequest'] = _GETCAMPAIGNGROUPREQUEST
DESCRIPTOR.message_types_by_name['MutateCampaignGroupsRequest'] = _MUTATECAMPAIGNGROUPSREQUEST
DESCRIPTOR.message_types_by_name['CampaignGroupOperation'] = _CAMPAIGNGROUPOPERATION
DESCRIPTOR.message_types_by_name['MutateCampaignGroupsResponse'] = _MUTATECAMPAIGNGROUPSRESPONSE
DESCRIPTOR.message_types_by_name['MutateCampaignGroupResult'] = _MUTATECAMPAIGNGROUPRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetCampaignGroupRequest = _reflection.GeneratedProtocolMessageType('GetCampaignGroupRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETCAMPAIGNGROUPREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.campaign_group_service_pb2'
  ,
  __doc__ = """Request message for
  [CampaignGroupService.GetCampaignGroup][google.ads.googleads.v0.services.CampaignGroupService.GetCampaignGroup].
  
  
  Attributes:
      resource_name:
          The resource name of the campaign group to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.GetCampaignGroupRequest)
  ))
_sym_db.RegisterMessage(GetCampaignGroupRequest)

MutateCampaignGroupsRequest = _reflection.GeneratedProtocolMessageType('MutateCampaignGroupsRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECAMPAIGNGROUPSREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.campaign_group_service_pb2'
  ,
  __doc__ = """Request message for
  [CampaignGroupService.MutateCampaignGroups][google.ads.googleads.v0.services.CampaignGroupService.MutateCampaignGroups].
  
  
  Attributes:
      customer_id:
          The ID of the customer whose campaign groups are being
          modified.
      operations:
          The list of operations to perform on individual campaign
          groups.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateCampaignGroupsRequest)
  ))
_sym_db.RegisterMessage(MutateCampaignGroupsRequest)

CampaignGroupOperation = _reflection.GeneratedProtocolMessageType('CampaignGroupOperation', (_message.Message,), dict(
  DESCRIPTOR = _CAMPAIGNGROUPOPERATION,
  __module__ = 'google.ads.google_ads.v0.proto.services.campaign_group_service_pb2'
  ,
  __doc__ = """A single operation (create, update, remove) on a campaign group.
  
  
  Attributes:
      update_mask:
          FieldMask that determines which resource fields are modified
          in an update.
      operation:
          The mutate operation.
      create:
          Create operation: No resource name is expected for the new
          campaign group.
      update:
          Update operation: The campaign group is expected to have a
          valid resource name.
      remove:
          Remove operation: A resource name for the removed campaign
          group is expected, in this format:
          ``customers/{customer_id}/campaignGroups/{campaign_group_id}``
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.CampaignGroupOperation)
  ))
_sym_db.RegisterMessage(CampaignGroupOperation)

MutateCampaignGroupsResponse = _reflection.GeneratedProtocolMessageType('MutateCampaignGroupsResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECAMPAIGNGROUPSRESPONSE,
  __module__ = 'google.ads.google_ads.v0.proto.services.campaign_group_service_pb2'
  ,
  __doc__ = """Response message for campaign group mutate.
  
  
  Attributes:
      results:
          All results for the mutate.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateCampaignGroupsResponse)
  ))
_sym_db.RegisterMessage(MutateCampaignGroupsResponse)

MutateCampaignGroupResult = _reflection.GeneratedProtocolMessageType('MutateCampaignGroupResult', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECAMPAIGNGROUPRESULT,
  __module__ = 'google.ads.google_ads.v0.proto.services.campaign_group_service_pb2'
  ,
  __doc__ = """The result for the campaign group mutate.
  
  
  Attributes:
      resource_name:
          Returned for successful operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateCampaignGroupResult)
  ))
_sym_db.RegisterMessage(MutateCampaignGroupResult)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n$com.google.ads.googleads.v0.servicesB\031CampaignGroupServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V0.Services\312\002 Google\\Ads\\GoogleAds\\V0\\Services'))

_CAMPAIGNGROUPSERVICE = _descriptor.ServiceDescriptor(
  name='CampaignGroupService',
  full_name='google.ads.googleads.v0.services.CampaignGroupService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=818,
  serialized_end=1244,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetCampaignGroup',
    full_name='google.ads.googleads.v0.services.CampaignGroupService.GetCampaignGroup',
    index=0,
    containing_service=None,
    input_type=_GETCAMPAIGNGROUPREQUEST,
    output_type=google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__group__pb2._CAMPAIGNGROUP,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0022\0220/v0/{resource_name=customers/*/campaignGroups/*}')),
  ),
  _descriptor.MethodDescriptor(
    name='MutateCampaignGroups',
    full_name='google.ads.googleads.v0.services.CampaignGroupService.MutateCampaignGroups',
    index=1,
    containing_service=None,
    input_type=_MUTATECAMPAIGNGROUPSREQUEST,
    output_type=_MUTATECAMPAIGNGROUPSRESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0028\"3/v0/customers/{customer_id=*}/campaignGroups:mutate:\001*')),
  ),
])
_sym_db.RegisterServiceDescriptor(_CAMPAIGNGROUPSERVICE)

DESCRIPTOR.services_by_name['CampaignGroupService'] = _CAMPAIGNGROUPSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/enums/feed_link_status.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/enums/feed_link_status.proto',
  package='google.ads.googleads.v0.enums',
  syntax='proto3',
  serialized_pb=_b('\n:google/ads/googleads_v0/proto/enums/feed_link_status.proto\x12\x1dgoogle.ads.googleads.v0.enums\"^\n\x12\x46\x65\x65\x64LinkStatusEnum\"H\n\x0e\x46\x65\x65\x64LinkStatus\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x0b\n\x07\x45NABLED\x10\x02\x12\x0b\n\x07REMOVED\x10\x03\x42\xc4\x01\n!com.google.ads.googleads.v0.enumsB\x13\x46\x65\x65\x64LinkStatusProtoP\x01ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v0/enums;enums\xa2\x02\x03GAA\xaa\x02\x1dGoogle.Ads.GoogleAds.V0.Enums\xca\x02\x1dGoogle\\Ads\\GoogleAds\\V0\\Enumsb\x06proto3')
)



_FEEDLINKSTATUSENUM_FEEDLINKSTATUS = _descriptor.EnumDescriptor(
  name='FeedLinkStatus',
  full_name='google.ads.googleads.v0.enums.FeedLinkStatusEnum.FeedLinkStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ENABLED', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REMOVED', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=115,
  serialized_end=187,
)
_sym_db.RegisterEnumDescriptor(_FEEDLINKSTATUSENUM_FEEDLINKSTATUS)


_FEEDLINKSTATUSENUM = _descriptor.Descriptor(
  name='FeedLinkStatusEnum',
  full_name='google.ads.googleads.v0.enums.FeedLinkStatusEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FEEDLINKSTATUSENUM_FEEDLINKSTATUS,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=93,
  serialized_end=187,
)

_FEEDLINKSTATUSENUM_FEEDLINKSTATUS.containing_type = _FEEDLINKSTATUSENUM
DESCRIPTOR.message_types_by_name['FeedLinkStatusEnum'] = _FEEDLINKSTATUSENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FeedLinkStatusEnum = _reflection.GeneratedProtocolMessageType('FeedLinkStatusEnum', (_message.Message,), dict(
  DESCRIPTOR = _FEEDLINKSTATUSENUM,
  __module__ = 'google.ads.google_ads.v0.proto.enums.feed_link_status_pb2'
  ,
  __doc__ = """Container for an enum describing possible statuses of a feed link.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.enums.FeedLinkStatusEnum)
  ))
_sym_db.RegisterMessage(FeedLinkStatusEnum)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n!com.google.ads.googleads.v0.enumsB\023FeedLinkStatusProtoP\001ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v0/enums;enums\242\002\003GAA\252\002\035Google.Ads.GoogleAds.V0.Enums\312\002\035Google\\Ads\\GoogleAds\\V0\\Enums'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/errors/campaign_group_error.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/errors/campaign_group_error.proto',
  package='google.ads.googleads.v0.errors',
  syntax='proto3',
  serialized_pb=_b('\n?google/ads/googleads_v0/proto/errors/campaign_group_error.proto\x12\x1egoogle.ads.googleads.v0.errors\"\xce\x01\n\x16\x43\x61mpaignGroupErrorEnum\"\xb3\x01\n\x12\x43\x61mpaignGroupError\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x41\n=CANNOT_REMOVE_CAMPAIGN_GROUP_WITH_ENABLED_OR_PAUSED_CAMPAIGNS\x10\x02\x12\x12\n\x0e\x44UPLICATE_NAME\x10\x03\x12(\n$CANNOT_MODIFY_REMOVED_CAMPAIGN_GROUP\x10\x04\x42\xcd\x01\n\"com.google.ads.googleads.v0.errorsB\x17\x43\x61mpaignGroupErrorProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v0/errors;errors\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V0.Errors\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V0\\Errorsb\x06proto3')
)



_CAMPAIGNGROUPERRORENUM_CAMPAIGNGROUPERROR = _descriptor.EnumDescriptor(
  name='CampaignGroupError',
  full_name='google.ads.googleads.v0.errors.CampaignGroupErrorEnum.CampaignGroupError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_REMOVE_CAMPAIGN_GROUP_WITH_ENABLED_OR_PAUSED_CAMPAIGNS', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DUPLICATE_NAME', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_MODIFY_REMOVED_CAMPAIGN_GROUP', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=127,
  serialized_end=306,
)
_sym_db.RegisterEnumDescriptor(_CAMPAIGNGROUPERRORENUM_CAMPAIGNGROUPERROR)


_CAMPAIGNGROUPERRORENUM = _descriptor.Descriptor(
  name='CampaignGroupErrorEnum',
  full_name='google.ads.googleads.v0.errors.CampaignGroupErrorEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CAMPAIGNGROUPERRORENUM_CAMPAIGNGROUPERROR,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=100,
  serialized_end=306,
)

_CAMPAIGNGROUPERRORENUM_CAMPAIGNGROUPERROR.containing_type = _CAMPAIGNGROUPERRORENUM
DESCRIPTOR.message_types_by_name['CampaignGroupErrorEnum'] = _CAMPAIGNGROUPERRORENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CampaignGroupErrorEnum = _reflection.GeneratedProtocolMessageType('CampaignGroupErrorEnum', (_message.Message,), dict(
  DESCRIPTOR = _CAMPAIGNGROUPERRORENUM,
  __module__ = 'google.ads.google_ads.v0.proto.errors.campaign_group_error_pb2'
  ,
  __doc__ = """Container for enum describing possible campaign group errors.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.errors.CampaignGroupErrorEnum)
  ))
_sym_db.RegisterMessage(CampaignGroupErrorEnum)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\"com.google.ads.googleads.v0.errorsB\027CampaignGroupErrorProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v0/errors;errors\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V0.Errors\312\002\036Google\\Ads\\GoogleAds\\V0\\Errors'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/errors/feed_attribute_reference_error.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/errors/feed_attribute_reference_error.proto',
  package='google.ads.googleads.v0.errors',
  syntax='proto3',
  serialized_pb=_b('\nIgoogle/ads/googleads_v0/proto/errors/feed_attribute_reference_error.proto\x12\x1egoogle.ads.googleads.v0.errors\"\xba\x01\n\x1f\x46\x65\x65\x64\x41ttributeReferenceErrorEnum\"\x96\x01\n\x1b\x46\x65\x65\x64\x41ttributeReferenceError\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12!\n\x1d\x43\x41NNOT_REFERENCE_DELETED_FEED\x10\x02\x12\x15\n\x11INVALID_FEED_NAME\x10\x03\x12\x1f\n\x1bINVALID_FEED_ATTRIBUTE_NAME\x10\x04\x42\xd6\x01\n\"com.google.ads.googleads.v0.errorsB FeedAttributeReferenceErrorProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v0/errors;errors\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V0.Errors\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V0\\Errorsb\x06proto3')
)



_FEEDATTRIBUTEREFERENCEERRORENUM_FEEDATTRIBUTEREFERENCEERROR = _descriptor.EnumDescriptor(
  name='FeedAttributeReferenceError',
  full_name='google.ads.googleads.v0.errors.FeedAttributeReferenceErrorEnum.FeedAttributeReferenceError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_REFERENCE_DELETED_FEED', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_FEED_NAME', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_FEED_ATTRIBUTE_NAME', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=146,
  serialized_end=296,
)
_sym_db.RegisterEnumDescriptor(_FEEDATTRIBUTEREFERENCEERRORENUM_FEEDATTRIBUTEREFERENCEERROR)


_FEEDATTRIBUTEREFERENCEERRORENUM = _descriptor.Descriptor(
  name='FeedAttributeReferenceErrorEnum',
  full_name='google.ads.googleads.v0.errors.FeedAttributeReferenceErrorEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FEEDATTRIBUTEREFERENCEERRORENUM_FEEDATTRIBUTEREFERENCEERROR,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=110,
  serialized_end=296,
)

_FEEDATTRIBUTEREFERENCEERRORENUM_FEEDATTRIBUTEREFERENCEERROR.containing_type = _FEEDATTRIBUTEREFERENCEERRORENUM
DESCRIPTOR.message_types_by_name['FeedAttributeReferenceErrorEnum'] = _FEEDATTRIBUTEREFERENCEERRORENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FeedAttributeReferenceErrorEnum = _reflection.GeneratedProtocolMessageType('FeedAttributeReferenceErrorEnum', (_message.Message,), dict(
  DESCRIPTOR = _FEEDATTRIBUTEREFERENCEERRORENUM,
  __module__ = 'google.ads.google_ads.v0.proto.errors.feed_attribute_reference_error_pb2'
  ,
  __doc__ = """Container for enum describing possible feed attribute reference errors.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.errors.FeedAttributeReferenceErrorEnum)
  ))
_sym_db.RegisterMessage(FeedAttributeReferenceErrorEnum)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\"com.google.ads.googleads.v0.errorsB FeedAttributeReferenceErrorProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v0/errors;errors\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V0.Errors\312\002\036Google\\Ads\\GoogleAds\\V0\\Errors'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/services/ad_group_feed_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v0.proto.resources import ad_group_feed_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_ad__group__feed__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/services/ad_group_feed_service.proto',
  package='google.ads.googleads.v0.services',
  syntax='proto3',
  serialized_pb=_b('\nBgoogle/ads/googleads_v0/proto/services/ad_group_feed_service.proto\x12 google.ads.googleads.v0.services\x1a;google/ads/googleads_v0/proto/resources/ad_group_feed.proto\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\".\n\x15GetAdGroupFeedRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"|\n\x19MutateAdGroupFeedsRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12J\n\noperations\x18\x02 \x03(\x0b\x32\x36.google.ads.googleads.v0.services.AdGroupFeedOperation\"\xea\x01\n\x14\x41\x64GroupFeedOperation\x12/\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12@\n\x06\x63reate\x18\x01 \x01(\x0b\x32..google.ads.googleads.v0.resources.AdGroupFeedH\x00\x12@\n\x06update\x18\x02 \x01(\x0b\x32..google.ads.googleads.v0.resources.AdGroupFeedH\x00\x12\x10\n\x06remove\x18\x03 \x01(\tH\x00\x42\x0b\n\toperation\"h\n\x1aMutateAdGroupFeedsResponse\x12J\n\x07results\x18\x02 \x03(\x0b\x32\x39.google.ads.googleads.v0.services.MutateAdGroupFeedResult\"0\n\x17MutateAdGroupFeedResult\x12\x15\n\rresource_name\x18\x01 \x01(\t2\x98\x03\n\x12\x41\x64GroupFeedService\x12\xb1\x01\n\x0eGetAdGroupFeed\x12\x37.google.ads.googleads.v0.services.GetAdGroupFeedRequest\x1a..google.ads.googleads.v0.resources.AdGroupFeed\"6\x82\xd3\xe4\x93\x02\x30\x12./v0/{resource_name=customers/*/adGroupFeeds/*}\x12\xcd\x01\n\x12MutateAdGroupFeeds\x12;.google.ads.googleads.v0.services.MutateAdGroupFeedsRequest\x1a<.google.ads.googleads.v0.services.MutateAdGroupFeedsResponse\"<\x82\xd3\xe4\x93\x02\x36\"1/v0/customers/{customer_id=*}/adGroupFeeds:mutate:\x01*B\xd7\x01\n$com.google.ads.googleads.v0.servicesB\x17\x41\x64GroupFeedServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V0.Services\xca\x02 Google\\Ads\\GoogleAds\\V0\\Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_ad__group__feed__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,])




_GETADGROUPFEEDREQUEST = _descriptor.Descriptor(
  name='GetAdGroupFeedRequest',
  full_name='google.ads.googleads.v0.services.GetAdGroupFeedRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.GetAdGroupFeedRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=229,
  serialized_end=275,
)


_MUTATEADGROUPFEEDSREQUEST = _descriptor.Descriptor(
  name='MutateAdGroupFeedsRequest',
  full_name='google.ads.googleads.v0.services.MutateAdGroupFeedsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v0.services.MutateAdGroupFeedsRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operations', full_name='google.ads.googleads.v0.services.MutateAdGroupFeedsRequest.operations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=277,
  serialized_end=401,
)


_ADGROUPFEEDOPERATION = _descriptor.Descriptor(
  name='AdGroupFeedOperation',
  full_name='google.ads.googleads.v0.services.AdGroupFeedOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='google.ads.googleads.v0.services.AdGroupFeedOperation.update_mask', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create', full_name='google.ads.googleads.v0.services.AdGroupFeedOperation.create', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update', full_name='google.ads.googleads.v0.services.AdGroupFeedOperation.update', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='google.ads.googleads.v0.services.AdGroupFeedOperation.remove', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='operation', full_name='google.ads.googleads.v0.services.AdGroupFeedOperation.operation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=404,
  serialized_end=638,
)


_MUTATEADGROUPFEEDSRESPONSE = _descriptor.Descriptor(
  name='MutateAdGroupFeedsResponse',
  full_name='google.ads.googleads.v0.services.MutateAdGroupFeedsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v0.services.MutateAdGroupFeedsResponse.results', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=640,
  serialized_end=744,
)


_MUTATEADGROUPFEEDRESULT = _descriptor.Descriptor(
  name='MutateAdGroupFeedResult',
  full_name='google.ads.googleads.v0.services.MutateAdGroupFeedResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.MutateAdGroupFeedResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=746,
  serialized_end=794,
)

_MUTATEADGROUPFEEDSREQUEST.fields_by_name['operations'].message_type = _ADGROUPFEEDOPERATION
_ADGROUPFEEDOPERATION.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_ADGROUPFEEDOPERATION.fields_by_name['create'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_ad__group__feed__pb2._ADGROUPFEED
_ADGROUPFEEDOPERATION.fields_by_name['update'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_ad__group__feed__pb2._ADGROUPFEED
_ADGROUPFEEDOPERATION.oneofs_by_name['operation'].fields.append(
  _ADGROUPFEEDOPERATION.fields_by_name['create'])
_ADGROUPFEEDOPERATION.fields_by_name['create'].containing_oneof = _ADGROUPFEEDOPERATION.oneofs_by_name['operation']
_ADGROUPFEEDOPERATION.oneofs_by_name['operation'].fields.append(
  _ADGROUPFEEDOPERATION.fields_by_name['update'])
_ADGROUPFEEDOPERATION.fields_by_name['update'].containing_oneof = _ADGROUPFEEDOPERATION.oneofs_by_name['operation']
_ADGROUPFEEDOPERATION.oneofs_by_name['operation'].fields.append(
  _ADGROUPFEEDOPERATION.fields_by_name['remove'])
_ADGROUPFEEDOPERATION.fields_by_name['remove'].containing_oneof = _ADGROUPFEEDOPERATION.oneofs_by_name['operation']
_MUTATEADGROUPFEEDSRESPONSE.fields_by_name['results'].message_type = _MUTATEADGROUPFEEDRESULT
DESCRIPTOR.message_types_by_name['GetAdGroupFeedRequest'] = _GETADGROUPFEEDREQUEST
DESCRIPTOR.message_types_by_name['MutateAdGroupFeedsRequest'] = _MUTATEADGROUPFEEDSREQUEST
DESCRIPTOR.message_types_by_name['AdGroupFeedOperation'] = _ADGROUPFEEDOPERATION
DESCRIPTOR.message_types_by_name['MutateAdGroupFeedsResponse'] = _MUTATEADGROUPFEEDSRESPONSE
DESCRIPTOR.message_types_by_name['MutateAdGroupFeedResult'] = _MUTATEADGROUPFEEDRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetAdGroupFeedRequest = _reflection.GeneratedProtocolMessageType('GetAdGroupFeedRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETADGROUPFEEDREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.ad_group_feed_service_pb2'
  ,
  __doc__ = """Request message for
  [AdGroupFeedService.GetAdGroupFeed][google.ads.googleads.v0.services.AdGroupFeedService.GetAdGroupFeed].
  
  
  Attributes:
      resource_name:
          The resource name of the ad group feed to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.GetAdGroupFeedRequest)
  ))
_sym_db.RegisterMessage(GetAdGroupFeedRequest)

MutateAdGroupFeedsRequest = _reflection.GeneratedProtocolMessageType('MutateAdGroupFeedsRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEADGROUPFEEDSREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.ad_group_feed_service_pb2'
  ,
  __doc__ = """Request message for
  [AdGroupFeedService.MutateAdGroupFeeds][google.ads.googleads.v0.services.AdGroupFeedService.MutateAdGroupFeeds].
  
  
  Attributes:
      customer_id:
          The ID of the customer whose ad group feeds are being
          modified.
      operations:
          The list of operations to perform on individual ad group
          feeds.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateAdGroupFeedsRequest)
  ))
_sym_db.RegisterMessage(MutateAdGroupFeedsRequest)

AdGroupFeedOperation = _reflection.GeneratedProtocolMessageType('AdGroupFeedOperation', (_message.Message,), dict(
  DESCRIPTOR = _ADGROUPFEEDOPERATION,
  __module__ = 'google.ads.google_ads.v0.proto.services.ad_group_feed_service_pb2'
  ,
  __doc__ = """A single operation (create, update, remove) on an ad group feed.
  
  
  Attributes:
      update_mask:
          FieldMask that determines which resource fields are modified
          in an update.
      operation:
          The mutate operation.
      create:
          Create operation: No resource name is expected for the new ad
          group feed.
      update:
          Update operation: The ad group feed is expected to have a
          valid resource name.
      remove:
          Remove operation: A resource name for the removed ad group
          feed is expected, in this format:  ``customers/{customer_id}/a
          dGroupFeeds/{ad_group_id}_{feed_id}``
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.AdGroupFeedOperation)
  ))
_sym_db.RegisterMessage(AdGroupFeedOperation)

MutateAdGroupFeedsResponse = _reflection.GeneratedProtocolMessageType('MutateAdGroupFeedsResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEADGROUPFEEDSRESPONSE,
  __module__ = 'google.ads.google_ads.v0.proto.services.ad_group_feed_service_pb2'
  ,
  __doc__ = """Response message for an ad group feed mutate.
  
  
  Attributes:
      results:
          All results for the mutate.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateAdGroupFeedsResponse)
  ))
_sym_db.RegisterMessage(MutateAdGroupFeedsResponse)

MutateAdGroupFeedResult = _reflection.GeneratedProtocolMessageType('MutateAdGroupFeedResult', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEADGROUPFEEDRESULT,
  __module__ = 'google.ads.google_ads.v0.proto.services.ad_group_feed_service_pb2'
  ,
  __doc__ = """The result for the ad group feed mutate.
  
  
  Attributes:
      resource_name:
          Returned for successful operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateAdGroupFeedResult)
  ))
_sym_db.RegisterMessage(MutateAdGroupFeedResult)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n$com.google.ads.googleads.v0.servicesB\027AdGroupFeedServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V0.Services\312\002 Google\\Ads\\GoogleAds\\V0\\Services'))

_ADGROUPFEEDSERVICE = _descriptor.ServiceDescriptor(
  name='AdGroupFeedService',
  full_name='google.ads.googleads.v0.services.AdGroupFeedService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=797,
  serialized_end=1205,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetAdGroupFeed',
    full_name='google.ads.googleads.v0.services.AdGroupFeedService.GetAdGroupFeed',
    index=0,
    containing_service=None,
    input_type=_GETADGROUPFEEDREQUEST,
    output_type=google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_ad__group__feed__pb2._ADGROUPFEED,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0020\022./v0/{resource_name=customers/*/adGroupFeeds/*}')),
  ),
  _descriptor.MethodDescriptor(
    name='MutateAdGroupFeeds',
    full_name='google.ads.googleads.v0.services.AdGroupFeedService.MutateAdGroupFeeds',
    index=1,
    containing_service=None,
    input_type=_MUTATEADGROUPFEEDSREQUEST,
    output_type=_MUTATEADGROUPFEEDSRESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0026\"1/v0/customers/{customer_id=*}/adGroupFeeds:mutate:\001*')),
  ),
])
_sym_db.RegisterServiceDescriptor(_ADGROUPFEEDSERVICE)

DESCRIPTOR.services_by_name['AdGroupFeedService'] = _ADGROUPFEEDSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/services/campaign_criterion_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v0.proto.resources import campaign_criterion_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__criterion__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/services/campaign_criterion_service.proto',
  package='google.ads.googleads.v0.services',
  syntax='proto3',
  serialized_pb=_b('\nGgoogle/ads/googleads_v0/proto/services/campaign_criterion_service.proto\x12 google.ads.googleads.v0.services\x1a@google/ads/googleads_v0/proto/resources/campaign_criterion.proto\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\"4\n\x1bGetCampaignCriterionRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"\x86\x01\n\x1dMutateCampaignCriteriaRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12P\n\noperations\x18\x02 \x03(\x0b\x32<.google.ads.googleads.v0.services.CampaignCriterionOperation\"\xfc\x01\n\x1a\x43\x61mpaignCriterionOperation\x12/\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x46\n\x06\x63reate\x18\x01 \x01(\x0b\x32\x34.google.ads.googleads.v0.resources.CampaignCriterionH\x00\x12\x46\n\x06update\x18\x02 \x01(\x0b\x32\x34.google.ads.googleads.v0.resources.CampaignCriterionH\x00\x12\x10\n\x06remove\x18\x03 \x01(\tH\x00\x42\x0b\n\toperation\"r\n\x1eMutateCampaignCriteriaResponse\x12P\n\x07results\x18\x02 \x03(\x0b\x32?.google.ads.googleads.v0.services.MutateCampaignCriterionResult\"6\n\x1dMutateCampaignCriterionResult\x12\x15\n\rresource_name\x18\x01 \x01(\t2\xc4\x03\n\x18\x43\x61mpaignCriterionService\x12\xc7\x01\n\x14GetCampaignCriterion\x12=.google.ads.googleads.v0.services.GetCampaignCriterionRequest\x1a\x34.google.ads.googleads.v0.resources.CampaignCriterion\":\x82\xd3\xe4\x93\x02\x34\x12\x32/v0/{resource_name=customers/*/campaignCriteria/*}\x12\xdd\x01\n\x16MutateCampaignCriteria\x12?.google.ads.googleads.v0.services.MutateCampaignCriteriaRequest\x1a@.google.ads.googleads.v0.services.MutateCampaignCriteriaResponse\"@\x82\xd3\xe4\x93\x02:\"5/v0/customers/{customer_id=*}/campaignCriteria:mutate:\x01*B\xdd\x01\n$com.google.ads.googleads.v0.servicesB\x1d\x43\x61mpaignCriterionServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V0.Services\xca\x02 Google\\Ads\\GoogleAds\\V0\\Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__criterion__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,])




_GETCAMPAIGNCRITERIONREQUEST = _descriptor.Descriptor(
  name='GetCampaignCriterionRequest',
  full_name='google.ads.googleads.v0.services.GetCampaignCriterionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.GetCampaignCriterionRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=239,
  serialized_end=291,
)


_MUTATECAMPAIGNCRITERIAREQUEST = _descriptor.Descriptor(
  name='MutateCampaignCriteriaRequest',
  full_name='google.ads.googleads.v0.services.MutateCampaignCriteriaRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v0.services.MutateCampaignCriteriaRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operations', full_name='google.ads.googleads.v0.services.MutateCampaignCriteriaRequest.operations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=294,
  serialized_end=428,
)


_CAMPAIGNCRITERIONOPERATION = _descriptor.Descriptor(
  name='CampaignCriterionOperation',
  full_name='google.ads.googleads.v0.services.CampaignCriterionOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='google.ads.googleads.v0.services.CampaignCriterionOperation.update_mask', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create', full_name='google.ads.googleads.v0.services.CampaignCriterionOperation.create', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update', full_name='google.ads.googleads.v0.services.CampaignCriterionOperation.update', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='google.ads.googleads.v0.services.CampaignCriterionOperation.remove', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='operation', full_name='google.ads.googleads.v0.services.CampaignCriterionOperation.operation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=431,
  serialized_end=683,
)


_MUTATECAMPAIGNCRITERIARESPONSE = _descriptor.Descriptor(
  name='MutateCampaignCriteriaResponse',
  full_name='google.ads.googleads.v0.services.MutateCampaignCriteriaResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v0.services.MutateCampaignCriteriaResponse.results', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=685,
  serialized_end=799,
)


_MUTATECAMPAIGNCRITERIONRESULT = _descriptor.Descriptor(
  name='MutateCampaignCriterionResult',
  full_name='google.ads.googleads.v0.services.MutateCampaignCriterionResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.MutateCampaignCriterionResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=801,
  serialized_end=855,
)

_MUTATECAMPAIGNCRITERIAREQUEST.fields_by_name['operations'].message_type = _CAMPAIGNCRITERIONOPERATION
_CAMPAIGNCRITERIONOPERATION.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_CAMPAIGNCRITERIONOPERATION.fields_by_name['create'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__criterion__pb2._CAMPAIGNCRITERION
_CAMPAIGNCRITERIONOPERATION.fields_by_name['update'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__criterion__pb2._CAMPAIGNCRITERION
_CAMPAIGNCRITERIONOPERATION.oneofs_by_name['operation'].fields.append(
  _CAMPAIGNCRITERIONOPERATION.fields_by_name['create'])
_CAMPAIGNCRITERIONOPERATION.fields_by_name['create'].containing_oneof = _CAMPAIGNCRITERIONOPERATION.oneofs_by_name['operation']
_CAMPAIGNCRITERIONOPERATION.oneofs_by_name['operation'].fields.append(
  _CAMPAIGNCRITERIONOPERATION.fields_by_name['update'])
_CAMPAIGNCRITERIONOPERATION.fields_by_name['update'].containing_oneof = _CAMPAIGNCRITERIONOPERATION.oneofs_by_name['operation']
_CAMPAIGNCRITERIONOPERATION.oneofs_by_name['operation'].fields.append(
  _CAMPAIGNCRITERIONOPERATION.fields_by_name['remove'])
_CAMPAIGNCRITERIONOPERATION.fields_by_name['remove'].containing_oneof = _CAMPAIGNCRITERIONOPERATION.oneofs_by_name['operation']
_MUTATECAMPAIGNCRITERIARESPONSE.fields_by_name['results'].message_type = _MUTATECAMPAIGNCRITERIONRESULT
DESCRIPTOR.message_types_by_name['GetCampaignCriterionRequest'] = _GETCAMPAIGNCRITERIONREQUEST
DESCRIPTOR.message_types_by_name['MutateCampaignCriteriaRequest'] = _MUTATECAMPAIGNCRITERIAREQUEST
DESCRIPTOR.message_types_by_name['CampaignCriterionOperation'] = _CAMPAIGNCRITERIONOPERATION
DESCRIPTOR.message_types_by_name['MutateCampaignCriteriaResponse'] = _MUTATECAMPAIGNCRITERIARESPONSE
DESCRIPTOR.message_types_by_name['MutateCampaignCriterionResult'] = _MUTATECAMPAIGNCRITERIONRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetCampaignCriterionRequest = _reflection.GeneratedProtocolMessageType('GetCampaignCriterionRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETCAMPAIGNCRITERIONREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.campaign_criterion_service_pb2'
  ,
  __doc__ = """Request message for
  [CampaignCriterionService.GetCampaignCriterion][google.ads.googleads.v0.services.CampaignCriterionService.GetCampaignCriterion].
  
  
  Attributes:
      resource_name:
          The resource name of the criterion to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.GetCampaignCriterionRequest)
  ))
_sym_db.RegisterMessage(GetCampaignCriterionRequest)

MutateCampaignCriteriaRequest = _reflection.GeneratedProtocolMessageType('MutateCampaignCriteriaRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECAMPAIGNCRITERIAREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.campaign_criterion_service_pb2'
  ,
  __doc__ = """Request message for
  [CampaignCriterionService.MutateCampaignCriteria][google.ads.googleads.v0.services.CampaignCriterionService.MutateCampaignCriteria].
  
  
  Attributes:
      customer_id:
          The ID of the customer whose criteria are being modified.
      operations:
          The list of operations to perform on individual criteria.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateCampaignCriteriaRequest)
  ))
_sym_db.RegisterMessage(MutateCampaignCriteriaRequest)

CampaignCriterionOperation = _reflection.GeneratedProtocolMessageType('CampaignCriterionOperation', (_message.Message,), dict(
  DESCRIPTOR = _CAMPAIGNCRITERIONOPERATION,
  __module__ = 'google.ads.google_ads.v0.proto.services.campaign_criterion_service_pb2'
  ,
  __doc__ = """A single operation (create, update, remove) on a campaign criterion.
  
  
  Attributes:
      update_mask:
          FieldMask that determines which resource fields are modified
          in an update.
      operation:
          The mutate operation.
      create:
          Create operation: No resource name is expected for the new
          criterion.
      update:
          Update operation: The criterion is expected to have a valid
          resource name.
      remove:
          Remove operation: A resource name for the removed criterion is
          expected, in this format:  ``customers/{customer_id}/campaignC
          riteria/{campaign_id}_{criterion_id}``
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.CampaignCriterionOperation)
  ))
_sym_db.RegisterMessage(CampaignCriterionOperation)

MutateCampaignCriteriaResponse = _reflection.GeneratedProtocolMessageType('MutateCampaignCriteriaResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECAMPAIGNCRITERIARESPONSE,
  __module__ = 'google.ads.google_ads.v0.proto.services.campaign_criterion_service_pb2'
  ,
  __doc__ = """Response message for campaign criterion mutate.
  
  
  Attributes:
      results:
          All results for the mutate.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateCampaignCriteriaResponse)
  ))
_sym_db.RegisterMessage(MutateCampaignCriteriaResponse)

MutateCampaignCriterionResult = _reflection.GeneratedProtocolMessageType('MutateCampaignCriterionResult', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECAMPAIGNCRITERIONRESULT,
  __module__ = 'google.ads.google_ads.v0.proto.services.campaign_criterion_service_pb2'
  ,
  __doc__ = """The result for the criterion mutate.
  
  
  Attributes:
      resource_name:
          Returned for successful operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateCampaignCriterionResult)
  ))
_sym_db.RegisterMessage(MutateCampaignCriterionResult)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n$com.google.ads.googleads.v0.servicesB\035CampaignCriterionServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V0.Services\312\002 Google\\Ads\\GoogleAds\\V0\\Services'))

_CAMPAIGNCRITERIONSERVICE = _descriptor.ServiceDescriptor(
  name='CampaignCriterionService',
  full_name='google.ads.googleads.v0.services.CampaignCriterionService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=858,
  serialized_end=1310,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetCampaignCriterion',
    full_name='google.ads.googleads.v0.services.CampaignCriterionService.GetCampaignCriterion',
    index=0,
    containing_service=None,
    input_type=_GETCAMPAIGNCRITERIONREQUEST,
    output_type=google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__criterion__pb2._CAMPAIGNCRITERION,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0024\0222/v0/{resource_name=customers/*/campaignCriteria/*}')),
  ),
  _descriptor.MethodDescriptor(
    name='MutateCampaignCriteria',
    full_name='google.ads.googleads.v0.services.CampaignCriterionService.MutateCampaignCriteria',
    index=1,
    containing_service=None,
    input_type=_MUTATECAMPAIGNCRITERIAREQUEST,
    output_type=_MUTATECAMPAIGNCRITERIARESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002:\"5/v0/customers/{customer_id=*}/campaignCriteria:mutate:\001*')),
  ),
])
_sym_db.RegisterServiceDescriptor(_CAMPAIGNCRITERIONSERVICE)

DESCRIPTOR.services_by_name['CampaignCriterionService'] = _CAMPAIGNCRITERIONSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/resources/campaign_group.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v0.proto.enums import campaign_group_status_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_campaign__group__status__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/resources/campaign_group.proto',
  package='google.ads.googleads.v0.resources',
  syntax='proto3',
  serialized_pb=_b('\n<google/ads/googleads_v0/proto/resources/campaign_group.proto\x12!google.ads.googleads.v0.resources\x1a?google/ads/googleads_v0/proto/enums/campaign_group_status.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xd7\x01\n\rCampaignGroup\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12\'\n\x02id\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12*\n\x04name\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12Z\n\x06status\x18\x05 \x01(\x0e\x32J.google.ads.googleads.v0.enums.CampaignGroupStatusEnum.CampaignGroupStatusB\xd7\x01\n%com.google.ads.googleads.v0.resourcesB\x12\x43\x61mpaignGroupProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v0/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V0.Resources\xca\x02!Google\\Ads\\GoogleAds\\V0\\Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_campaign__group__status__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])




_CAMPAIGNGROUP = _descriptor.Descriptor(
  name='CampaignGroup',
  full_name='google.ads.googleads.v0.resources.CampaignGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.resources.CampaignGroup.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='google.ads.googleads.v0.resources.CampaignGroup.id', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='google.ads.googleads.v0.resources.CampaignGroup.name', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='google.ads.googleads.v0.resources.CampaignGroup.status', index=3,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=197,
  serialized_end=412,
)

_CAMPAIGNGROUP.fields_by_name['id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CAMPAIGNGROUP.fields_by_name['name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CAMPAIGNGROUP.fields_by_name['status'].enum_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_campaign__group__status__pb2._CAMPAIGNGROUPSTATUSENUM_CAMPAIGNGROUPSTATUS
DESCRIPTOR.message_types_by_name['CampaignGroup'] = _CAMPAIGNGROUP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CampaignGroup = _reflection.GeneratedProtocolMessageType('CampaignGroup', (_message.Message,), dict(
  DESCRIPTOR = _CAMPAIGNGROUP,
  __module__ = 'google.ads.google_ads.v0.proto.resources.campaign_group_pb2'
  ,
  __doc__ = """A campaign group.
  
  
  Attributes:
      resource_name:
          The resource name of the campaign group. Campaign group
          resource names have the form:
          ``customers/{customer_id}/campaignGroups/{campaign_group_id}``
      id:
          The ID of the campaign group.
      name:
          The name of the campaign group.  This field is required and
          should not be empty when creating new campaign groups.  It
          must not contain any null (code point 0x0), NL line feed (code
          point 0xA) or carriage return (code point 0xD) characters.
      status:
          The status of the campaign group.  When a new campaign group
          is added, the status defaults to ENABLED.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.resources.CampaignGroup)
  ))
_sym_db.RegisterMessage(CampaignGroup)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n%com.google.ads.googleads.v0.resourcesB\022CampaignGroupProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v0/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V0.Resources\312\002!Google\\Ads\\GoogleAds\\V0\\Resources'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/common/matching_function.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/common/matching_function.proto',
  package='google.ads.googleads.v0.common',
  syntax='proto3',
  serialized_pb=_b('\n<google/ads/googleads_v0/proto/common/matching_function.proto\x12\x1egoogle.ads.googleads.v0.common\x1a\x1egoogle/protobuf/wrappers.proto\"I\n\x10MatchingFunction\x12\x35\n\x0f\x66unction_string\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\xcb\x01\n\"com.google.ads.googleads.v0.commonB\x15MatchingFunctionProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v0/common;common\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V0.Common\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V0\\Commonb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])




_MATCHINGFUNCTION = _descriptor.Descriptor(
  name='MatchingFunction',
  full_name='google.ads.googleads.v0.common.MatchingFunction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='function_string', full_name='google.ads.googleads.v0.common.MatchingFunction.function_string', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=128,
  serialized_end=201,
)

_MATCHINGFUNCTION.fields_by_name['function_string'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
DESCRIPTOR.message_types_by_name['MatchingFunction'] = _MATCHINGFUNCTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MatchingFunction = _reflection.GeneratedProtocolMessageType('MatchingFunction', (_message.Message,), dict(
  DESCRIPTOR = _MATCHINGFUNCTION,
  __module__ = 'google.ads.google_ads.v0.proto.common.matching_function_pb2'
  ,
  __doc__ = """Matching function associated with a CustomerFeed, CampaignFeed, or
  AdGroupFeed. The matching function is used to filter the set of feed
  items selected.
  
  
  Attributes:
      function_string:
          String representation of the Function.  Examples: 1)
          IDENTITY(true) or IDENTITY(false). All or none feed items
          serve. 2) EQUALS(CONTEXT.DEVICE,"Mobile") 3)
          IN(FEED\_ITEM\_ID,{1000001,1000002,1000003}) 4)
          CONTAINS\_ANY(FeedAttribute[12345678,0],{"Mars cruise","Venus
          cruise"}) 5) AND(IN(FEED\_ITEM\_ID,{10001,10002}),EQUALS(CONTE
          XT.DEVICE,"Mobile")) See https:
          //developers.google.com/adwords/api/docs/guides/feed-matching-
          functions  Note that because multiple strings may represent
          the same underlying function (whitespace and single versus
          double quotation marks, for example), the value returned may
          not be identical to the string sent in a mutate request.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.common.MatchingFunction)
  ))
_sym_db.RegisterMessage(MatchingFunction)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\"com.google.ads.googleads.v0.commonB\025MatchingFunctionProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v0/common;common\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V0.Common\312\002\036Google\\Ads\\GoogleAds\\V0\\Common'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/services/keyword_plan_campaign_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v0.proto.resources import keyword_plan_campaign_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_keyword__plan__campaign__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/services/keyword_plan_campaign_service.proto',
  package='google.ads.googleads.v0.services',
  syntax='proto3',
  serialized_pb=_b('\nJgoogle/ads/googleads_v0/proto/services/keyword_plan_campaign_service.proto\x12 google.ads.googleads.v0.services\x1a\x43google/ads/googleads_v0/proto/resources/keyword_plan_campaign.proto\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\"6\n\x1dGetKeywordPlanCampaignRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"\x8c\x01\n!MutateKeywordPlanCampaignsRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12R\n\noperations\x18\x02 \x03(\x0b\x32>.google.ads.googleads.v0.services.KeywordPlanCampaignOperation\"\x82\x02\n\x1cKeywordPlanCampaignOperation\x12/\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12H\n\x06\x63reate\x18\x01 \x01(\x0b\x32\x36.google.ads.googleads.v0.resources.KeywordPlanCampaignH\x00\x12H\n\x06update\x18\x02 \x01(\x0b\x32\x36.google.ads.googleads.v0.resources.KeywordPlanCampaignH\x00\x12\x10\n\x06remove\x18\x03 \x01(\tH\x00\x42\x0b\n\toperation\"x\n\"MutateKeywordPlanCampaignsResponse\x12R\n\x07results\x18\x02 \x03(\x0b\x32\x41.google.ads.googleads.v0.services.MutateKeywordPlanCampaignResult\"8\n\x1fMutateKeywordPlanCampaignResult\x12\x15\n\rresource_name\x18\x01 \x01(\t2\xe0\x03\n\x1aKeywordPlanCampaignService\x12\xd1\x01\n\x16GetKeywordPlanCampaign\x12?.google.ads.googleads.v0.services.GetKeywordPlanCampaignRequest\x1a\x36.google.ads.googleads.v0.resources.KeywordPlanCampaign\">\x82\xd3\xe4\x93\x02\x38\x12\x36/v0/{resource_name=customers/*/keywordPlanCampaigns/*}\x12\xed\x01\n\x1aMutateKeywordPlanCampaigns\x12\x43.google.ads.googleads.v0.services.MutateKeywordPlanCampaignsRequest\x1a\x44.google.ads.googleads.v0.services.MutateKeywordPlanCampaignsResponse\"D\x82\xd3\xe4\x93\x02>\"9/v0/customers/{customer_id=*}/keywordPlanCampaigns:mutate:\x01*B\xdf\x01\n$com.google.ads.googleads.v0.servicesB\x1fKeywordPlanCampaignServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V0.Services\xca\x02 Google\\Ads\\GoogleAds\\V0\\Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_keyword__plan__campaign__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,])




_GETKEYWORDPLANCAMPAIGNREQUEST = _descriptor.Descriptor(
  name='GetKeywordPlanCampaignRequest',
  full_name='google.ads.googleads.v0.services.GetKeywordPlanCampaignRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.GetKeywordPlanCampaignRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=245,
  serialized_end=299,
)


_MUTATEKEYWORDPLANCAMPAIGNSREQUEST = _descriptor.Descriptor(
  name='MutateKeywordPlanCampaignsRequest',
  full_name='google.ads.googleads.v0.services.MutateKeywordPlanCampaignsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v0.services.MutateKeywordPlanCampaignsRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operations', full_name='google.ads.googleads.v0.services.MutateKeywordPlanCampaignsRequest.operations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=302,
  serialized_end=442,
)


_KEYWORDPLANCAMPAIGNOPERATION = _descriptor.Descriptor(
  name='KeywordPlanCampaignOperation',
  full_name='google.ads.googleads.v0.services.KeywordPlanCampaignOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='google.ads.googleads.v0.services.KeywordPlanCampaignOperation.update_mask', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create', full_name='google.ads.googleads.v0.services.KeywordPlanCampaignOperation.create', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update', full_name='google.ads.googleads.v0.services.KeywordPlanCampaignOperation.update', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='google.ads.googleads.v0.services.KeywordPlanCampaignOperation.remove', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='operation', full_name='google.ads.googleads.v0.services.KeywordPlanCampaignOperation.operation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=445,
  serialized_end=703,
)


_MUTATEKEYWORDPLANCAMPAIGNSRESPONSE = _descriptor.Descriptor(
  name='MutateKeywordPlanCampaignsResponse',
  full_name='google.ads.googleads.v0.services.MutateKeywordPlanCampaignsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v0.services.MutateKeywordPlanCampaignsResponse.results', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=705,
  serialized_end=825,
)


_MUTATEKEYWORDPLANCAMPAIGNRESULT = _descriptor.Descriptor(
  name='MutateKeywordPlanCampaignResult',
  full_name='google.ads.googleads.v0.services.MutateKeywordPlanCampaignResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.MutateKeywordPlanCampaignResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=827,
  serialized_end=883,
)

_MUTATEKEYWORDPLANCAMPAIGNSREQUEST.fields_by_name['operations'].message_type = _KEYWORDPLANCAMPAIGNOPERATION
_KEYWORDPLANCAMPAIGNOPERATION.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_KEYWORDPLANCAMPAIGNOPERATION.fields_by_name['create'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_keyword__plan__campaign__pb2._KEYWORDPLANCAMPAIGN
_KEYWORDPLANCAMPAIGNOPERATION.fields_by_name['update'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_keyword__plan__campaign__pb2._KEYWORDPLANCAMPAIGN
_KEYWORDPLANCAMPAIGNOPERATION.oneofs_by_name['operation'].fields.append(
  _KEYWORDPLANCAMPAIGNOPERATION.fields_by_name['create'])
_KEYWORDPLANCAMPAIGNOPERATION.fields_by_name['create'].containing_oneof = _KEYWORDPLANCAMPAIGNOPERATION.oneofs_by_name['operation']
_KEYWORDPLANCAMPAIGNOPERATION.oneofs_by_name['operation'].fields.append(
  _KEYWORDPLANCAMPAIGNOPERATION.fields_by_name['update'])
_KEYWORDPLANCAMPAIGNOPERATION.fields_by_name['update'].containing_oneof = _KEYWORDPLANCAMPAIGNOPERATION.oneofs_by_name['operation']
_KEYWORDPLANCAMPAIGNOPERATION.oneofs_by_name['operation'].fields.append(
  _KEYWORDPLANCAMPAIGNOPERATION.fields_by_name['remove'])
_KEYWORDPLANCAMPAIGNOPERATION.fields_by_name['remove'].containing_oneof = _KEYWORDPLANCAMPAIGNOPERATION.oneofs_by_name['operation']
_MUTATEKEYWORDPLANCAMPAIGNSRESPONSE.fields_by_name['results'].message_type = _MUTATEKEYWORDPLANCAMPAIGNRESULT
DESCRIPTOR.message_types_by_name['GetKeywordPlanCampaignRequest'] = _GETKEYWORDPLANCAMPAIGNREQUEST
DESCRIPTOR.message_types_by_name['MutateKeywordPlanCampaignsRequest'] = _MUTATEKEYWORDPLANCAMPAIGNSREQUEST
DESCRIPTOR.message_types_by_name['KeywordPlanCampaignOperation'] = _KEYWORDPLANCAMPAIGNOPERATION
DESCRIPTOR.message_types_by_name['MutateKeywordPlanCampaignsResponse'] = _MUTATEKEYWORDPLANCAMPAIGNSRESPONSE
DESCRIPTOR.message_types_by_name['MutateKeywordPlanCampaignResult'] = _MUTATEKEYWORDPLANCAMPAIGNRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetKeywordPlanCampaignRequest = _reflection.GeneratedProtocolMessageType('GetKeywordPlanCampaignRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETKEYWORDPLANCAMPAIGNREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.keyword_plan_campaign_service_pb2'
  ,
  __doc__ = """Request message for
  [KeywordPlanCampaignService.GetKeywordPlanCampaign][google.ads.googleads.v0.services.KeywordPlanCampaignService.GetKeywordPlanCampaign].
  
  
  Attributes:
      resource_name:
          The resource name of the Keyword Plan campaign to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.GetKeywordPlanCampaignRequest)
  ))
_sym_db.RegisterMessage(GetKeywordPlanCampaignRequest)

MutateKeywordPlanCampaignsRequest = _reflection.GeneratedProtocolMessageType('MutateKeywordPlanCampaignsRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEKEYWORDPLANCAMPAIGNSREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.keyword_plan_campaign_service_pb2'
  ,
  __doc__ = """Request message for
  [KeywordPlanCampaignService.MutateKeywordPlanCampaigns][google.ads.googleads.v0.services.KeywordPlanCampaignService.MutateKeywordPlanCampaigns].
  
  
  Attributes:
      customer_id:
          The ID of the customer whose Keyword Plan campaigns are being
          modified.
      operations:
          The list of operations to perform on individual Keyword Plan
          campaigns.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateKeywordPlanCampaignsRequest)
  ))
_sym_db.RegisterMessage(MutateKeywordPlanCampaignsRequest)

KeywordPlanCampaignOperation = _reflection.GeneratedProtocolMessageType('KeywordPlanCampaignOperation', (_message.Message,), dict(
  DESCRIPTOR = _KEYWORDPLANCAMPAIGNOPERATION,
  __module__ = 'google.ads.google_ads.v0.proto.services.keyword_plan_campaign_service_pb2'
  ,
  __doc__ = """A single operation (create, update, remove) on a Keyword Plan campaign.
  
  
  Attributes:
      update_mask:
          The FieldMask that determines which resource fields are
          modified in an update.
      operation:
          The mutate operation.
      create:
          Create operation: No resource name is expected for the new
          Keyword Plan campaign.
      update:
          Update operation: The Keyword Plan campaign is expected to
          have a valid resource name.
      remove:
          Remove operation: A resource name for the removed Keyword Plan
          campaign is expected, in this format:  ``customers/{customer_i
          d}/keywordPlanCampaigns/{keywordPlan_campaign_id}``
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.KeywordPlanCampaignOperation)
  ))
_sym_db.RegisterMessage(KeywordPlanCampaignOperation)

MutateKeywordPlanCampaignsResponse = _reflection.GeneratedProtocolMessageType('MutateKeywordPlanCampaignsResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEKEYWORDPLANCAMPAIGNSRESPONSE,
  __module__ = 'google.ads.google_ads.v0.proto.services.keyword_plan_campaign_service_pb2'
  ,
  __doc__ = """Response message for a Keyword Plan campaign mutate.
  
  
  Attributes:
      results:
          All results for the mutate.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateKeywordPlanCampaignsResponse)
  ))
_sym_db.RegisterMessage(MutateKeywordPlanCampaignsResponse)

MutateKeywordPlanCampaignResult = _reflection.GeneratedProtocolMessageType('MutateKeywordPlanCampaignResult', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEKEYWORDPLANCAMPAIGNRESULT,
  __module__ = 'google.ads.google_ads.v0.proto.services.keyword_plan_campaign_service_pb2'
  ,
  __doc__ = """The result for the Keyword Plan campaign mutate.
  
  
  Attributes:
      resource_name:
          Returned for successful operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateKeywordPlanCampaignResult)
  ))
_sym_db.RegisterMessage(MutateKeywordPlanCampaignResult)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n$com.google.ads.googleads.v0.servicesB\037KeywordPlanCampaignServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V0.Services\312\002 Google\\Ads\\GoogleAds\\V0\\Services'))

_KEYWORDPLANCAMPAIGNSERVICE = _descriptor.ServiceDescriptor(
  name='KeywordPlanCampaignService',
  full_name='google.ads.googleads.v0.services.KeywordPlanCampaignService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=886,
  serialized_end=1366,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetKeywordPlanCampaign',
    full_name='google.ads.googleads.v0.services.KeywordPlanCampaignService.GetKeywordPlanCampaign',
    index=0,
    containing_service=None,
    input_type=_GETKEYWORDPLANCAMPAIGNREQUEST,
    output_type=google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_keyword__plan__campaign__pb2._KEYWORDPLANCAMPAIGN,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0028\0226/v0/{resource_name=customers/*/keywordPlanCampaigns/*}')),
  ),
  _descriptor.MethodDescriptor(
    name='MutateKeywordPlanCampaigns',
    full_name='google.ads.googleads.v0.services.KeywordPlanCampaignService.MutateKeywordPlanCampaigns',
    index=1,
    containing_service=None,
    input_type=_MUTATEKEYWORDPLANCAMPAIGNSREQUEST,
    output_type=_MUTATEKEYWORDPLANCAMPAIGNSRESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002>\"9/v0/customers/{customer_id=*}/keywordPlanCampaigns:mutate:\001*')),
  ),
])
_sym_db.RegisterServiceDescriptor(_KEYWORDPLANCAMPAIGNSERVICE)

DESCRIPTOR.services_by_name['KeywordPlanCampaignService'] = _KEYWORDPLANCAMPAIGNSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/services/campaign_budget_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v0.proto.resources import campaign_budget_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__budget__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/services/campaign_budget_service.proto',
  package='google.ads.googleads.v0.services',
  syntax='proto3',
  serialized_pb=_b('\nDgoogle/ads/googleads_v0/proto/services/campaign_budget_service.proto\x12 google.ads.googleads.v0.services\x1a=google/ads/googleads_v0/proto/resources/campaign_budget.proto\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\"1\n\x18GetCampaignBudgetRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"\x82\x01\n\x1cMutateCampaignBudgetsRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12M\n\noperations\x18\x02 \x03(\x0b\x32\x39.google.ads.googleads.v0.services.CampaignBudgetOperation\"\xf3\x01\n\x17\x43\x61mpaignBudgetOperation\x12/\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x43\n\x06\x63reate\x18\x01 \x01(\x0b\x32\x31.google.ads.googleads.v0.resources.CampaignBudgetH\x00\x12\x43\n\x06update\x18\x02 \x01(\x0b\x32\x31.google.ads.googleads.v0.resources.CampaignBudgetH\x00\x12\x10\n\x06remove\x18\x03 \x01(\tH\x00\x42\x0b\n\toperation\"n\n\x1dMutateCampaignBudgetsResponse\x12M\n\x07results\x18\x02 \x03(\x0b\x32<.google.ads.googleads.v0.services.MutateCampaignBudgetResult\"3\n\x1aMutateCampaignBudgetResult\x12\x15\n\rresource_name\x18\x01 \x01(\t2\xb3\x03\n\x15\x43\x61mpaignBudgetService\x12\xbd\x01\n\x11GetCampaignBudget\x12:.google.ads.googleads.v0.services.GetCampaignBudgetRequest\x1a\x31.google.ads.googleads.v0.resources.CampaignBudget\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/v0/{resource_name=customers/*/campaignBudgets/*}\x12\xd9\x01\n\x15MutateCampaignBudgets\x12>.google.ads.googleads.v0.services.MutateCampaignBudgetsRequest\x1a?.google.ads.googleads.v0.services.MutateCampaignBudgetsResponse\"?\x82\xd3\xe4\x93\x02\x39\"4/v0/customers/{customer_id=*}/campaignBudgets:mutate:\x01*B\xda\x01\n$com.google.ads.googleads.v0.servicesB\x1a\x43\x61mpaignBudgetServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V0.Services\xca\x02 Google\\Ads\\GoogleAds\\V0\\Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__budget__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,])




_GETCAMPAIGNBUDGETREQUEST = _descriptor.Descriptor(
  name='GetCampaignBudgetRequest',
  full_name='google.ads.googleads.v0.services.GetCampaignBudgetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.GetCampaignBudgetRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=233,
  serialized_end=282,
)


_MUTATECAMPAIGNBUDGETSREQUEST = _descriptor.Descriptor(
  name='MutateCampaignBudgetsRequest',
  full_name='google.ads.googleads.v0.services.MutateCampaignBudgetsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v0.services.MutateCampaignBudgetsRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operations', full_name='google.ads.googleads.v0.services.MutateCampaignBudgetsRequest.operations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=285,
  serialized_end=415,
)


_CAMPAIGNBUDGETOPERATION = _descriptor.Descriptor(
  name='CampaignBudgetOperation',
  full_name='google.ads.googleads.v0.services.CampaignBudgetOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='google.ads.googleads.v0.services.CampaignBudgetOperation.update_mask', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create', full_name='google.ads.googleads.v0.services.CampaignBudgetOperation.create', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update', full_name='google.ads.googleads.v0.services.CampaignBudgetOperation.update', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='google.ads.googleads.v0.services.CampaignBudgetOperation.remove', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='operation', full_name='google.ads.googleads.v0.services.CampaignBudgetOperation.operation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=418,
  serialized_end=661,
)


_MUTATECAMPAIGNBUDGETSRESPONSE = _descriptor.Descriptor(
  name='MutateCampaignBudgetsResponse',
  full_name='google.ads.googleads.v0.services.MutateCampaignBudgetsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v0.services.MutateCampaignBudgetsResponse.results', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=663,
  serialized_end=773,
)


_MUTATECAMPAIGNBUDGETRESULT = _descriptor.Descriptor(
  name='MutateCampaignBudgetResult',
  full_name='google.ads.googleads.v0.services.MutateCampaignBudgetResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.MutateCampaignBudgetResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=775,
  serialized_end=826,
)

_MUTATECAMPAIGNBUDGETSREQUEST.fields_by_name['operations'].message_type = _CAMPAIGNBUDGETOPERATION
_CAMPAIGNBUDGETOPERATION.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_CAMPAIGNBUDGETOPERATION.fields_by_name['create'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__budget__pb2._CAMPAIGNBUDGET
_CAMPAIGNBUDGETOPERATION.fields_by_name['update'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__budget__pb2._CAMPAIGNBUDGET
_CAMPAIGNBUDGETOPERATION.oneofs_by_name['operation'].fields.append(
  _CAMPAIGNBUDGETOPERATION.fields_by_name['create'])
_CAMPAIGNBUDGETOPERATION.fields_by_name['create'].containing_oneof = _CAMPAIGNBUDGETOPERATION.oneofs_by_name['operation']
_CAMPAIGNBUDGETOPERATION.oneofs_by_name['operation'].fields.append(
  _CAMPAIGNBUDGETOPERATION.fields_by_name['update'])
_CAMPAIGNBUDGETOPERATION.fields_by_name['update'].containing_oneof = _CAMPAIGNBUDGETOPERATION.oneofs_by_name['operation']
_CAMPAIGNBUDGETOPERATION.oneofs_by_name['operation'].fields.append(
  _CAMPAIGNBUDGETOPERATION.fields_by_name['remove'])
_CAMPAIGNBUDGETOPERATION.fields_by_name['remove'].containing_oneof = _CAMPAIGNBUDGETOPERATION.oneofs_by_name['operation']
_MUTATECAMPAIGNBUDGETSRESPONSE.fields_by_name['results'].message_type = _MUTATECAMPAIGNBUDGETRESULT
DESCRIPTOR.message_types_by_name['GetCampaignBudgetRequest'] = _GETCAMPAIGNBUDGETREQUEST
DESCRIPTOR.message_types_by_name['MutateCampaignBudgetsRequest'] = _MUTATECAMPAIGNBUDGETSREQUEST
DESCRIPTOR.message_types_by_name['CampaignBudgetOperation'] = _CAMPAIGNBUDGETOPERATION
DESCRIPTOR.message_types_by_name['MutateCampaignBudgetsResponse'] = _MUTATECAMPAIGNBUDGETSRESPONSE
DESCRIPTOR.message_types_by_name['MutateCampaignBudgetResult'] = _MUTATECAMPAIGNBUDGETRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetCampaignBudgetRequest = _reflection.GeneratedProtocolMessageType('GetCampaignBudgetRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETCAMPAIGNBUDGETREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.campaign_budget_service_pb2'
  ,
  __doc__ = """Request message for
  [CampaignBudgetService.GetCampaignBudget][google.ads.googleads.v0.services.CampaignBudgetService.GetCampaignBudget].
  
  
  Attributes:
      resource_name:
          The resource name of the campaign budget to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.GetCampaignBudgetRequest)
  ))
_sym_db.RegisterMessage(GetCampaignBudgetRequest)

MutateCampaignBudgetsRequest = _reflection.GeneratedProtocolMessageType('MutateCampaignBudgetsRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECAMPAIGNBUDGETSREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.campaign_budget_service_pb2'
  ,
  __doc__ = """Request message for
  [CampaignBudgetService.MutateCampaignBudgets][google.ads.googleads.v0.services.CampaignBudgetService.MutateCampaignBudgets].
  
  
  Attributes:
      customer_id:
          The ID of the customer whose campaign budgets are being
          modified.
      operations:
          The list of operations to perform on individual campaign
          budgets.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateCampaignBudgetsRequest)
  ))
_sym_db.RegisterMessage(MutateCampaignBudgetsRequest)

CampaignBudgetOperation = _reflection.GeneratedProtocolMessageType('CampaignBudgetOperation', (_message.Message,), dict(
  DESCRIPTOR = _CAMPAIGNBUDGETOPERATION,
  __module__ = 'google.ads.google_ads.v0.proto.services.campaign_budget_service_pb2'
  ,
  __doc__ = """A single operation (create, update, remove) on a campaign budget.
  
  
  Attributes:
      update_mask:
          FieldMask that determines which resource fields are modified
          in an update.
      operation:
          The mutate operation.
      create:
          Create operation: No resource name is expected for the new
          budget.
      update:
          Update operation: The campaign budget is expected to have a
          valid resource name.
      remove:
          Remove operation: A resource name for the removed budget is
          expected, in this format:
          ``customers/{customer_id}/campaignBudgets/{budget_id}``
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.CampaignBudgetOperation)
  ))
_sym_db.RegisterMessage(CampaignBudgetOperation)

MutateCampaignBudgetsResponse = _reflection.GeneratedProtocolMessageType('MutateCampaignBudgetsResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECAMPAIGNBUDGETSRESPONSE,
  __module__ = 'google.ads.google_ads.v0.proto.services.campaign_budget_service_pb2'
  ,
  __doc__ = """Response message for campaign budget mutate.
  
  
  Attributes:
      results:
          All results for the mutate.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateCampaignBudgetsResponse)
  ))
_sym_db.RegisterMessage(MutateCampaignBudgetsResponse)

MutateCampaignBudgetResult = _reflection.GeneratedProtocolMessageType('MutateCampaignBudgetResult', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECAMPAIGNBUDGETRESULT,
  __module__ = 'google.ads.google_ads.v0.proto.services.campaign_budget_service_pb2'
  ,
  __doc__ = """The result for the campaign budget mutate.
  
  
  Attributes:
      resource_name:
          Returned for successful operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateCampaignBudgetResult)
  ))
_sym_db.RegisterMessage(MutateCampaignBudgetResult)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n$com.google.ads.googleads.v0.servicesB\032CampaignBudgetServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V0.Services\312\002 Google\\Ads\\GoogleAds\\V0\\Services'))

_CAMPAIGNBUDGETSERVICE = _descriptor.ServiceDescriptor(
  name='CampaignBudgetService',
  full_name='google.ads.googleads.v0.services.CampaignBudgetService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=829,
  serialized_end=1264,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetCampaignBudget',
    full_name='google.ads.googleads.v0.services.CampaignBudgetService.GetCampaignBudget',
    index=0,
    containing_service=None,
    input_type=_GETCAMPAIGNBUDGETREQUEST,
    output_type=google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__budget__pb2._CAMPAIGNBUDGET,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0023\0221/v0/{resource_name=customers/*/campaignBudgets/*}')),
  ),
  _descriptor.MethodDescriptor(
    name='MutateCampaignBudgets',
    full_name='google.ads.googleads.v0.services.CampaignBudgetService.MutateCampaignBudgets',
    index=1,
    containing_service=None,
    input_type=_MUTATECAMPAIGNBUDGETSREQUEST,
    output_type=_MUTATECAMPAIGNBUDGETSRESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0029\"4/v0/customers/{customer_id=*}/campaignBudgets:mutate:\001*')),
  ),
])
_sym_db.RegisterServiceDescriptor(_CAMPAIGNBUDGETSERVICE)

DESCRIPTOR.services_by_name['CampaignBudgetService'] = _CAMPAIGNBUDGETSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/enums/criterion_category_locale_availability_mode.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/enums/criterion_category_locale_availability_mode.proto',
  package='google.ads.googleads.v0.enums',
  syntax='proto3',
  serialized_pb=_b('\nUgoogle/ads/googleads_v0/proto/enums/criterion_category_locale_availability_mode.proto\x12\x1dgoogle.ads.googleads.v0.enums\"\xe1\x01\n+CriterionCategoryLocaleAvailabilityModeEnum\"\xb1\x01\n\'CriterionCategoryLocaleAvailabilityMode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x0f\n\x0b\x41LL_LOCALES\x10\x02\x12\x1d\n\x19\x43OUNTRY_AND_ALL_LANGUAGES\x10\x03\x12\x1e\n\x1aLANGUAGE_AND_ALL_COUNTRIES\x10\x04\x12\x18\n\x14\x43OUNTRY_AND_LANGUAGE\x10\x05\x42\xdd\x01\n!com.google.ads.googleads.v0.enumsB,CriterionCategoryLocaleAvailabilityModeProtoP\x01ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v0/enums;enums\xa2\x02\x03GAA\xaa\x02\x1dGoogle.Ads.GoogleAds.V0.Enums\xca\x02\x1dGoogle\\Ads\\GoogleAds\\V0\\Enumsb\x06proto3')
)



_CRITERIONCATEGORYLOCALEAVAILABILITYMODEENUM_CRITERIONCATEGORYLOCALEAVAILABILITYMODE = _descriptor.EnumDescriptor(
  name='CriterionCategoryLocaleAvailabilityMode',
  full_name='google.ads.googleads.v0.enums.CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALL_LOCALES', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COUNTRY_AND_ALL_LANGUAGES', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LANGUAGE_AND_ALL_COUNTRIES', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COUNTRY_AND_LANGUAGE', index=5, number=5,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=169,
  serialized_end=346,
)
_sym_db.RegisterEnumDescriptor(_CRITERIONCATEGORYLOCALEAVAILABILITYMODEENUM_CRITERIONCATEGORYLOCALEAVAILABILITYMODE)


_CRITERIONCATEGORYLOCALEAVAILABILITYMODEENUM = _descriptor.Descriptor(
  name='CriterionCategoryLocaleAvailabilityModeEnum',
  full_name='google.ads.googleads.v0.enums.CriterionCategoryLocaleAvailabilityModeEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CRITERIONCATEGORYLOCALEAVAILABILITYMODEENUM_CRITERIONCATEGORYLOCALEAVAILABILITYMODE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=121,
  serialized_end=346,
)

_CRITERIONCATEGORYLOCALEAVAILABILITYMODEENUM_CRITERIONCATEGORYLOCALEAVAILABILITYMODE.containing_type = _CRITERIONCATEGORYLOCALEAVAILABILITYMODEENUM
DESCRIPTOR.message_types_by_name['CriterionCategoryLocaleAvailabilityModeEnum'] = _CRITERIONCATEGORYLOCALEAVAILABILITYMODEENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CriterionCategoryLocaleAvailabilityModeEnum = _reflection.GeneratedProtocolMessageType('CriterionCategoryLocaleAvailabilityModeEnum', (_message.Message,), dict(
  DESCRIPTOR = _CRITERIONCATEGORYLOCALEAVAILABILITYMODEENUM,
  __module__ = 'google.ads.google_ads.v0.proto.enums.criterion_category_locale_availability_mode_pb2'
  ,
  __doc__ = """Describes locale availabilty mode for a criterion availability - whether
  it's available globally, or a particular country with all languages, or
  a particular language with all countries, or a country-language pair.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.enums.CriterionCategoryLocaleAvailabilityModeEnum)
  ))
_sym_db.RegisterMessage(CriterionCategoryLocaleAvailabilityModeEnum)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n!com.google.ads.googleads.v0.enumsB,CriterionCategoryLocaleAvailabilityModeProtoP\001ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v0/enums;enums\242\002\003GAA\252\002\035Google.Ads.GoogleAds.V0.Enums\312\002\035Google\\Ads\\GoogleAds\\V0\\Enums'))
# @@protoc_insertion_point(module_scope)
